# Monarch Utilities

This module provides helpful utility methods and classes for Monarch Digital projects.

## Installation

```
composer require monarch/monarch_utilities
drush en monarch_utilities -y
```

## EntityFieldValue

Quickly get the value of any field from a fieldable entity without all the annoying rigmarole. See class documentation for all available options.

Usage
```
$node = Node::load($nid);
$string = (new EntityFieldValue($node, 'field_string'))->getStringValue();
$bool = (new EntityFieldValue($node, 'field_boolean'))->getBooleanValue();
$date_string = (new EntityFieldValue($node, 'field_datetime'))->getDateStringValue('m/d/Y');
$date_object = (new EntityFieldValue($node, 'field_datetime'))->getDateTimeObject();
$target_id = (new EntityFieldValue($node, 'field_entityreference'))->getTargetID();
$entity = (new EntityFieldValue($node, 'field_entityreference'))->getReferencedEntity();
```

## Traits

This module provides a few helpful traits for quick use in custom classes

**CurrentUserTrait**

Adds the current user service to the class.

Usage:
```
class MyClass {
  use \Drupal\monarch_utilities\CurrentUserTrait;

  public function myMethod() {
    $current_user = $this->getCurrentUser();
  }
}
```

**FormDependencyTrait**

Add a dependency to a form element via the States API. See trait documentation
for all available options.

Simple Usage (controls 'visible' state by default):
```
$this->addDependency($form['myElement'], 'dependee', 'dependent');
```

## Render Elements

### Table Container
The table container element fixes a bug in the core table element that prevents
forms from working inside of tables.

See https://www.drupal.org/project/drupal/issues/3016258.
